@@ -24,6 +24,7 @@ CliPlugin::CliPlugin(QObject *parent, const QVariantList & args)
         : CliInterface(parent, args)
         , m_archiveType(ArchiveType7z)
         , m_parseState(ParseStateTitle)
+        , m_binaryVariant(Undefined)
         , m_linesComment(0)
         , m_isFirstInformationEntry(true)
 {
@@ -47,11 +48,30 @@ void CliPlugin::setupCliProperties()
 {
     qCDebug(ARK) << "Setting up parameters...";
 
+    if (m_binaryVariant == Undefined) {
+        qCDebug(ARK) << "Checking 7z variant...";
+        QProcess process;
+        process.setProgram(QStringLiteral("7z"));
+        process.start();
+        process.waitForFinished(500);
+        const QString output = QString::fromUtf8(process.readAllStandardOutput());
+        if (output.contains(QLatin1String("p7zip"))) {
+            qCDebug(ARK) << "Detected p7zip variant.";
+            m_binaryVariant = P7zip;
+        } else if (output.contains(QLatin1String("7-Zip"))) {
+            qCDebug(ARK) << "Detected upstream 7-Zip variant.";
+            m_binaryVariant = Upstream7zip;
+        }
+    }
+
     m_cliProps->setProperty("captureProgress", false);
 
     m_cliProps->setProperty("addProgram", QStringLiteral("7z"));
-    m_cliProps->setProperty("addSwitch", QStringList{QStringLiteral("a"),
-                                                 QStringLiteral("-l")});
+    QStringList addSwitch = {QStringLiteral("a")};
+    if (m_binaryVariant == P7zip) {
+        addSwitch << QStringLiteral("-l");
+    }
+    m_cliProps->setProperty("addSwitch", addSwitch);
 
     m_cliProps->setProperty("deleteProgram", QStringLiteral("7z"));
     m_cliProps->setProperty("deleteSwitch", QStringLiteral("d"));
@@ -112,6 +132,7 @@ bool CliPlugin::readListLine(const QString& line)
     }
 
     const QRegularExpression rxVersionLine(QStringLiteral("^p7zip Version ([\\d\\.]+) .*$"));
+    const QRegularExpression rxVersionLine7z(QStringLiteral("^7-Zip \\(z\\) ([\\d\\.]+) .*$"));
     QRegularExpressionMatch matchVersion;
 
     switch (m_parseState) {
@@ -121,6 +142,14 @@ bool CliPlugin::readListLine(const QString& line)
             m_parseState = ParseStateHeader;
             const QString p7zipVersion = matchVersion.captured(1);
             qCDebug(ARK) << "p7zip version" << p7zipVersion << "detected";
+	    break;
+        }
+	matchVersion = rxVersionLine7z.match(line);
+        if (matchVersion.hasMatch()) {
+            m_parseState = ParseStateHeader;
+            const QString l7zipVersion = matchVersion.captured(1);
+            qCDebug(ARK) << "7zip version" << l7zipVersion << "detected";
+	    break;
         }
         break;
 
@@ -294,7 +323,7 @@ bool CliPlugin::readDeleteLine(const QString &line)
 {
     if (line.startsWith(QLatin1String("Error: ")) &&
         line.endsWith(QLatin1String(" is not supported archive"))) {
-        Q_EMIT error(i18n("Delete operation failed. Try upgrading p7zip or disabling the p7zip plugin in the configuration dialog."));
+        Q_EMIT error(i18n("Delete operation failed. Try upgrading 7z or disabling the 7z plugin in the configuration dialog."));
         return false;
     }
 
@@ -333,7 +362,7 @@ void CliPlugin::handleMethods(const QStringList &methods)
 
 bool CliPlugin::isPasswordPrompt(const QString &line)
 {
-    return line.startsWith(QLatin1String("Enter password (will not be echoed):"));
+    return line.startsWith(QLatin1String("Enter password"));
 }
 
 bool CliPlugin::isWrongPasswordMsg(const QString &line)
